@@ -86,7 +86,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54500
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54600
 #  endif
 #endif
 
@@ -121,6 +121,12 @@
 #else
 #  define KTEXTWIDGETS_DEPRECATED_VERSION_5_65(text)
 #endif
+
+#if KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54600
+#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_70(text) KTEXTWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KTEXTWIDGETS_DEPRECATED_VERSION_5_70(text)
+#endif
 #define KTEXTWIDGETS_DEPRECATED_VERSION_5(minor, text)      KTEXTWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KTEXTWIDGETS_DEPRECATED_VERSION(major, minor, text) KTEXTWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 
